      *_> CNLLSTSPLF SRCFILE(@2/@1) SRCMBR(@3)
      *_> DLTMOD MODULE(@5/@4)
      *_> CRTRPGMOD MODULE(@5/@4) SRCFILE(@2/@1) SRCMBR(@3) +
      *_>   DBGVIEW(@9) OPTIMIZE(@8) OPTION(*EVENTF)
      * ---------------------------------------------------------------
      * Module.: XVIDAT_M02           Project.....:
      * Author.: A. Campin            Date written: 05/10/2007
      * Purpose: Convert date data types to an Integer Number.
      *          Valid date formats:
      *            *CCYMD  - ISO date CCYYMMDD
      *            *CYMD   - One Digit Century. CYYMMDD.
      *            *MDY    - MMDDYY.
      *            *YMD    - YYMMDD.
      *            *DMY    - DDMMYY.
      *            *MDCCYY - MMDDCCYY.
      *            *JUL    - YYJUL - Julian.
      *            *LJUL   - CCYYJUL - Long Julian.
      *            *JDEJUL - CYYJUL - J.D. Edwards Julian.
      *            *CJUL   - CYYJUL - CYYDDD. Same as *JDEJUL.
      *          Anything else returns an error.
      * ---------------------------------------------------------------
      * Called by: SQL Runtime.
      * ---------------------------------------------------------------
      * Revision history:
      *  Project # Pgmr        Date   Desc
      *
      * End Revision History
      * ---------------------------------------------------------------
     h nomain
     h Option(*Srcstmt:*Nodebugio)

      /copy *libl/qsrcf,cb_Std_Con

      /copy *libl/qsrcf,cb_StdType

      /copy *libl/qsrcf,xvidat_pr

      * Default date format for this system. If your system has a different
      *  default data format, change it here.
     d cDefaultFormat...
     d                 c                   '*CYMD'
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_ConvertToIseriesDefault
      *   This function is receives a date data type and assuming a
      *     default format.
      *      Input      - Date Data Type.
      *                   In Date Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Integer in format requested.
      *                   Return Integer Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     p IDAT_ConvertToIseriesDefault...
     p                 b                   Export
     d                 pi
     d   InDate...
     d                                     Like(StdDat)
     d   OutIntegerDate...
     d                                     Like(StdInt)
     d   InDateNull...
     d                                     Like(StdIntSml)
     d   OutNull...
     d                                     Like(StdIntSml)
     d   OutSQLState...
     d                                     Like(StdSQLState)
     d   InFunctionName...
     d                              139a   Varying
     d   InSpecificName...
     d                              128a   Varying
     d   OutDiagnosticMessage...
     d                               70a   Varying

     d DefaultFormat...
     d                 s             10a    Varying
     d                                      Inz(cDefaultFormat)
     d FormatNull...
     d                 s                   Like(StdIntSml)
     d                                     Inz(0)

      /Free

       OutSQLState = cSQLStateOk;

       IDAT_ConvertToIseries(InDate              :
                             DefaultFormat       :
                             OutIntegerDate      :
                             InDateNull          :
                             FormatNull          :
                             OutNull             :
                             OutSQLState         :
                             InFunctionName      :
                             InSpecificName      :
                             OutDiagnosticMessage);

       Return;

      /End-Free
     p                 e
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      * IDAT_ConvertToIseries
      *   This function is receive a date data type and converts to integer value based on
      *     format requested.
      *      Input      - Date Data Type.
      *                   Date Format
      *                   In Date Null.
      *                   In Format Null.
      *                   Function Name being called.
      *                   Specific Name.
      *      Output     - Return Integer
      *                   Return Integer Null.
      *                   SQL State on Exit.
      *                   Diagnostic Message.
      *      Returns    - None.
      *      Output     - None
      *      Returns    - None.
      * - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
     p IDAT_ConvertToIseries...
     p                 b                   Export
     d                 pi
     d   InDate...
     d                                     Like(StdDat)
     d   InDateFormat...
     d                               10a   Varying
     d   OutInteger...
     d                                     Like(StdInt)
     d   InDateNull...
     d                                     Like(StdIntSml)
     d   InFormatNull...
     d                                     Like(StdIntSml)
     d   OutNull...
     d                                     Like(StdIntSml)
     d   OutSQLState...
     d                                     Like(StdSQLState)
     d   InFunctionName...
     d                              139a   Varying
     d   InSpecificName...
     d                              128a   Varying
     d   OutDiagnosticMessage...
     d                               70a   Varying

     d Up              c                   'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
     d Lo              c                   'abcdefghijklmnopqrstuvwxyz'

     d CenturyNumber...
     d                 s                   Like(StdChr)
      /Free

       OutSQLState  = cSQLStateOk;
       InDateFormat = %Xlate(Lo:Up:InDateFormat);
       OutNull      = 0;

       If InDateNull = -1;
         OutInteger = 0;
         Return;
       EndIf;

       Select;
         When InDateFormat = '*CYMD';
           OutInteger = %Int(%Char(InDate:*CYMD0));
         When InDateFormat = '*CCYMD';
           OutInteger = %Int(%Char(InDate:*ISO0));
         When InDateFormat = '*MDY';
           OutInteger = %Int(%Char(InDate:*MDY0));
         When InDateFormat = '*YMD';
           OutInteger = %Int(%Char(InDate:*YMD0));
         When InDateFormat = '*DMY';
           OutInteger = %Int(%Char(InDate:*DMY0));
         When InDateFormat = '*MDCCYY';
           OutInteger = %Int(%Char(InDate:*USA0));
         When InDateFormat = '*JUL';
           OutInteger = %Int(%Char(InDate:*JUL0));
         When InDateFormat = '*LJUL';
           OutInteger = %Int(%Char(InDate:*LONGJUL0));
         When InDateFormat = '*CJUL' Or
              InDateFormat = '*JDEJUL';
           // No direct support for CJUL so we fudgeit.
           CenturyNumber = %Subst(%Char(InDate:*CYMD0):1:1);
           OutInteger    = %Int(CenturyNumber + %Char(InDate:*JUL0));
         Other;
           OutSQLState = '38501';
           OutDiagnosticMessage = 'Date Format ' +
                                  %Trim(InDateFormat) +
                                  ' invalid!';
           OutNull = -1;
       EndSl;

       Return;

      /End-Free
     p                 e
